@@ -10,7 +10,7 @@
 #include <ctype.h>
 #include "netacct.h"
 
-char *rcs_revision_config_c = "$Revision: 1.9 $";
+char *rcs_revision_config_c = "$Revision: 1.9be $";
 
 /* 
  * This routine reads all the configuration from the file fname.
@@ -35,10 +35,12 @@ struct config *read_config(char *fname)
     cfg -> ignorenet = NULL;
     cfg -> dontignore = NULL;
     cfg -> promisc = NULL;
+    cfg -> notdev = NULL;
     cfg -> fdelay = DEFAULT_FDELAY;
     cfg -> disabled = 0;
     cfg -> dynamicip = NULL;
     cfg -> excludenamelookup = NULL;
+
     debug_level = 0;
     dev2line = NULL;
 
@@ -246,6 +248,21 @@ struct config *read_config(char *fname)
 					   cfg->promisc->name);
 				}
 			}
+		    else if(strcasecmp(kwd, "notdev")==0)
+			{
+			    struct promisc_device *tmp;
+
+			    tmp = malloc(sizeof(struct promisc_device));
+			
+			    if(tmp != NULL)
+				{
+				    tmp -> name  = strdup(value);
+				    tmp -> next = cfg -> notdev;
+				    cfg -> notdev = tmp;
+				    syslog(LOG_DEBUG,"config: added notdevice %s\n",
+					   cfg->notdev->name);
+				}
+			}
 		    else if(strcasecmp(kwd, "errdelay")==0)
 			{
 			    cfg->err_delay = atoi(value);
