@@ -11,7 +11,7 @@
 #include <signal.h>
 #include "netacct.h"
 
-char *rcs_revision_main_c = "$Revision: 1.13 $";
+char *rcs_revision_main_c = "$Revision: 1.13be $";
 
 /* globals */
 char *progname;
@@ -22,11 +22,13 @@ FILE *dbg_file;
 
 static char *fname = NULL;
 static int debug = 0;
+static int daem = 1;
 
 void usage(void)
 {
-   fprintf(stderr, "Usage: %s [-d] [-c filename]\n\n\t-d\tSwitch on debugging\n", progname);
-   fprintf(stderr, "\t-c\tSpecify alternative configuration file\n\n");
+   fprintf(stderr, "Usage: %s [-dD] [-c filename]\n\n\t-d\tSwitch on debugging\n", progname);
+   fprintf(stderr, "\t-c\tSpecify alternative configuration file\n");
+   fprintf(stderr, "\t-D\tDon't detach (for inittab)\n\n");
 }
 
 void process_options(int argc, char *argv[])
@@ -35,7 +37,7 @@ void process_options(int argc, char *argv[])
 
    fname = strdup(DEF_ACCTTAB);
    
-   while ((c = getopt( argc, argv, "c:d" )) != EOF)
+   while ((c = getopt( argc, argv, "c:dD" )) != EOF)
        {
 	   switch (c)
 	       {
@@ -46,6 +48,9 @@ void process_options(int argc, char *argv[])
 	       case 'd':
 		   debug = 1;
 		   break;
+	       case 'D':
+	           daem = 0;
+	           break;
 	       case '?':
 	       default:
 		   usage();
@@ -204,7 +209,7 @@ int main(int argc, char *argv[])
 
     save_dumpfile(cfg->dumpname);
 
-    if(!debug)
+    if(!debug && daem)
 	{
 	    /* start daemon */
 	    if(daemon_start()!=-1)
