@@ -23,7 +23,7 @@
 #endif
 
 #ifndef _PATH_UTMP
-#define _PATH_UTMP "/var/adm/utmp"
+#define _PATH_UTMP "/var/run/utmp"
 #endif
 
 #define DEF_ACCTTAB "/etc/naccttab"
@@ -48,15 +48,19 @@
 
 
 #define MIN_DISABLE 2
-#define MAX_DISABLE 6
+#define MAX_DISABLE 10
 
 #define DIS_PROTO 2
 #define DIS_SRC 3
 #define DIS_SRCPORT 4
 #define DIS_DST 5
 #define DIS_DSTPORT 6
+#define DIS_COUNT 7
+#define DIS_BYTES 8
+#define DIS_DEV 9
+#define DIS_USER 10
 
-#define BITMASK(bit) (1 << ((bit) % CHAR_BIT))
+#define BITMASK(bit) (1 << ((bit) % (CHAR_BIT*sizeof(int))))
 
 /* parsing of config file */
 #define DBG_CONFIG	(1 << 1) 
@@ -111,10 +115,11 @@ struct config
     struct ipnetwork *ignorenet;
     struct ipnetwork *dontignore;
     struct promisc_device *promisc;
+    struct promisc_device *notdev;
     struct ipnetwork dynamicnet;
     struct ipnetwork *excludenamelookup;
     char *dynamicip;
-    char disabled; /* disabled output fields */
+    int disabled; /* disabled output fields */
 };
 
 struct dev2line
@@ -139,6 +144,7 @@ struct dynadat
 struct statistics
 {
     unsigned long int unenc;
+    unsigned long int notdev;
     unsigned long int ignored, netignored, local, ip, dropped;		/* sum = total */
     unsigned long int ip_udp, ip_tcp, ip_icmp, ip_other;	/* sum = ip */
 };
@@ -149,6 +155,7 @@ struct ipdata
     unsigned char proto;
     unsigned short srcport, dstport;
     unsigned long int bytes;
+    unsigned count;
     char *devname;
     char *user;
     
